@@ -4,9 +4,9 @@
 """
 
 from __future__ import absolute_import
-from .tagenalgo import *
+from .tagenalgo import TAGenAlgo
 from .backtest import *
 from .utils import *
 
-__version__ = '1.0.2'
+__version__ = '1.0.6'
 __license__ = 'BSD'
\ No newline at end of file
